@@ -73,6 +73,7 @@ describe 'horizon' do
           "    'enable_quotas': True,",
           "    'enable_security_group': True,",
           'API_RESULT_LIMIT = 1000',
+          'API_RESULT_PAGE_SIZE = 20',
           'DROPDOWN_MAX_ITEMS = 30',
           'TIME_ZONE = "UTC"',
           "            'handlers': ['file'],",
@@ -106,7 +107,8 @@ describe 'horizon' do
           :secondary_endpoint_type        => 'ANY-VALUE',
           :django_debug                   => true,
           :site_branding                  => 'mysite',
-          :api_result_limit               => 4682,
+          :api_result_limit               => 2000,
+          :api_result_page_size           => 40,
           :dropdown_max_items             => 123,
           :compress_offline               => false,
           :hypervisor_options             => {'can_set_mount_point' => false, 'can_set_password' => true },
@@ -192,7 +194,8 @@ describe 'horizon' do
           "    'enable_scheduler_hints': True,",
           'OPENSTACK_ENDPOINT_TYPE = "internalURL"',
           'SECONDARY_ENDPOINT_TYPE = "ANY-VALUE"',
-          'API_RESULT_LIMIT = 4682',
+          'API_RESULT_LIMIT = 2000',
+          'API_RESULT_PAGE_SIZE = 40',
           'DROPDOWN_MAX_ITEMS = 123',
           'TIME_ZONE = "Asia/Shanghai"',
           "AVAILABLE_THEMES = [",
@@ -206,6 +209,7 @@ describe 'horizon' do
           'COMPRESS_OFFLINE = False',
           "FILE_UPLOAD_TEMP_DIR = '/var/spool/horizon'",
           "OVERVIEW_DAYS_RANGE = 1",
+          'DISALLOW_IFRAME_EMBED = True',
         ])
       end
 
@@ -557,16 +561,16 @@ describe 'horizon' do
       end
     end
 
-    context 'with disallow iframe embed enabled' do
+    context 'with disallow iframe embed disabled' do
       before do
         params.merge!({
-                        :disallow_iframe_embed => true
+                        :disallow_iframe_embed => false
                       })
       end
 
       it 'disallow_iframe_embed is configured' do
         verify_concat_fragment_contents(catalogue, 'local_settings.py', [
-                                          'HORIZON_CONFIG["disallow_iframe_embed"] = True',
+                                          'DISALLOW_IFRAME_EMBED = False',
                                         ])
       end
     end
@@ -693,7 +697,20 @@ describe 'horizon' do
       end
       it 'sets HORIZON_IMAGES_UPLOAD_MODE in local_settings.py' do
         verify_concat_fragment_contents(catalogue, 'local_settings.py', [
-	  'HORIZON_IMAGES_UPLOAD_MODE = direct',
+          'HORIZON_IMAGES_UPLOAD_MODE = "direct"',
+        ])
+      end
+    end
+
+    context 'with upload mode with quotes' do
+      before do
+        params.merge!({
+          :horizon_upload_mode  => '"direct"',
+        })
+      end
+      it 'sets HORIZON_IMAGES_UPLOAD_MODE in local_settings.py' do
+        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
+          'HORIZON_IMAGES_UPLOAD_MODE = "direct"',
         ])
       end
     end
